┌   ┐
54
└   ┘

summaryrefslogtreecommitdiff
path: root/src/dolphiniconsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/dolphiniconsview.h')
-rw-r--r--src/dolphiniconsview.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/dolphiniconsview.h b/src/dolphiniconsview.h
index 69481eb7f..7e88f39bd 100644
--- a/src/dolphiniconsview.h
+++ b/src/dolphiniconsview.h
@@ -60,7 +60,7 @@ protected:
private slots:
void slotShowPreviewChanged(bool show);
- void slotShowAdditionalInfoChanged(bool show);
+ void slotAdditionalInfoCountChanged(int count);
void zoomIn();
void zoomOut();
@@ -76,9 +76,9 @@ private:
/**
* Updates the size of the grid depending on the state
* of \a showPreview and \a showAdditionalInfo.
*/
- void updateGridSize(bool showPreview, bool showAdditionalInfo);
+ void updateGridSize(bool showPreview, int additionalInfoCount);
private:
DolphinController* m_controller;
@@ -76,9 +76,9 @@ private:
/**
* Updates the size of the grid depending on the state
- * of \a showPreview and \a showAdditionalInfo.
+ * of \a showPreview and \a additionalInfoCount.
*/